#ifdef HAVE_CONFIG_H
  #include "elementary_config.h"
#endif

#define EFL_ACCESS_VALUE_PROTECTED

#include "elm_priv.h"

#include "efl_access_value.eo.c"
